/* 1a_expenditures_voluntary: This do-file prepares the voluntary expenditure data */

clear
clear all
set more off

/*****************************************/
/* Globals */
/*****************************************/

/* working folder*/
global DIR ""

/* folder Jahresrechnungsstatistik */
global DIR_JHR ""

/*****************************************/
/* Selection Gruppierungs and Gliederungs-Number */
/*****************************************/

#delimit ;
local kreis = "$KREIS" ;
local gruppierung "	4
			50
			51
			52
			53
			54
			55
			56
			63
			65
			66
			93
			94
			 ";

local gliederung " 0 10 11 13 16 21 22 23 27 28 31 32 33 34 35 36 43 451 452 454 460 461 463 464 465 467 468 47 55 56 57 58 59 86 63 65 67 68 82 60 61 62 78 79 84 73 76 77";	
#delimit cr

local glied0 0
local glied1 10 11 13 16
local glied2 21 22 23 27 28
local glied3 31 32 33 34 35 36
local glied4 43 451 452 454 460 461 463 464 465 467 468 47
local glied5 55 56 57 58 59 86
local glied6 60 61 62 63 65 67 68 
local glied61 63 65 67 68 
local glied62 60 61 62
local glied7 73 76 77
local glied10 78 79 84

local list1
foreach var in `gliederung' {
	local list1 `list1' *x`var'
}

/*****************************************/
/* Load data sets and required variables */
/*****************************************/

use AGS_2007 year `list1' using "${DIR_JHR}\JHR.dta", clear
capture confirm numeric variable AGS_2007
if _rc!=0 {
	destring AGS_2007, replace
}
ren AGS_2007 id_AGS
local testlist id_AGS year
foreach var in `gruppierung' {
	local testlist `testlist' EF`var'x*
}
quietly ds `testlist'
local testlist2 `r(varlist)'
keep `testlist2'


/*****************************************/
/* Include county expenditures allocated using population */
/*****************************************/

if ("`kreis'"=="ja") {
	gen kreis = int(id_AGS / 1000)

	preserve
	use kreis year `list1' using "${DIR_JHR}\JHR_KREISE.dta", clear
	local testlist kreis year
	foreach var in `gruppierung' {
		local testlist `testlist' KREIS_EF`var'x*
	}
	quietly ds `testlist'
	local testlist2 `r(varlist)'
	keep `testlist2'
	tempfile kreisausgaben
	save "${DIR_JHR}\`kreisausgaben'", replace
	restore
	merge m:1 kreis year using "${DIR_JHR}\`kreisausgaben'", keep(1 3) nogenerate
	drop kreis
	merge 1:1 id_AGS year using "{DIR_JHR}\POP", keep(1 3) nogenerate ///
	keepusing(pop)
	
	gen id_kreis=int(id_AGS/1000)
	bys id_kreis year: egen pop_kreis = sum(pop)
	
	ds EF*
	foreach var in `r(varlist)' {
		ren `var' old_`var'
		capture replace KREIS_`var' = KREIS_`var'*(pop / pop_kreis)
		if _rc==0 {
			capture egen `var'=rowtotal(old_`var' KREIS_`var')
			replace `var'=. if (old_`var'==. & KREIS_`var'==.) | pop == .
			drop old_`var' KREIS_`var'
		}
		if _rc!=0 {
			egen `var'=rowtotal(old_`var')
			replace `var'=. if (old_`var'==.) | pop == .
			drop old_`var'
		}
	}

	drop pop pop_kreis
}
if ("`kreis'"=="nein") {
	capture drop KREIS_*
}

/*****************************************/
/* Create expenditure variables */
/*****************************************/

local ll
foreach var in `glied0' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_admin = rowtotal(`ll')
replace exp_admin = . if help == 0 
label var exp_admin "Administration Exp."

local ll
foreach var in `glied1' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_security = rowtotal(`ll')
replace exp_security = . if help == 0 
label var exp_security "Security Exp."

local ll
foreach var in `glied2' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_schools = rowtotal(`ll')
replace exp_schools = . if help == 0 
label var exp_schools "Schools Exp."

local ll
foreach var in `glied3' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_culture = rowtotal(`ll')
replace exp_culture = . if help == 0 
label var exp_culture "Culture Exp."

local ll
foreach var in `glied4' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_social = rowtotal(`ll')
replace exp_social = . if help == 0 
label var exp_social "Social Exp."

local ll
foreach var in `glied5' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_recreation = rowtotal(`ll')
replace exp_recreation = . if help == 0 
label var exp_recreation "Recreation"

local ll
foreach var in `glied6' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_bau = rowtotal(`ll')
replace exp_bau = . if help == 0 
label var exp_bau "Streets Exp."


local ll
foreach var in `glied61' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_traffic = rowtotal(`ll')
replace exp_traffic = . if help == 0 
label var exp_traffic "Streets (narrow) Exp."

local ll
foreach var in `glied62' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_housing = rowtotal(`ll')
replace exp_housing = . if help == 0 
label var exp_housing "Housing Exp."

local ll
foreach var in `glied10' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_econ_promo = rowtotal(`ll')
replace exp_econ_promo = . if help == 0 
label var exp_econ_promo "Economic Promotion Exp."

local ll
foreach var in `glied7' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_public = rowtotal(`ll')
replace exp_public = . if help == 0 
label var exp_public "Public Facilities Exp."

local list2 exp_*
keep id_AGS year `list2'

/*****************************************/
/* Save data set*/
/*****************************************/

save "${DIR}/data/JHR_kategorien_prep.dta", replace
