
/* 1b_expenditures_total: This do-file prepares the overall (voluntary and mandatory) expenditure data */

clear
clear all
set more off

/*****************************************/
/* Globals */
/*****************************************/

/* working folder*/
global DIR ""

/* folder Jahresrechnungsstatistik*/
global DIR_JHR "C:\Users\msimmler\OneDrive - Saïd Business School\Home Folder\Daten\Municipalities Germany\Jahresrechnungsstatistik\JHR_Kategorien\Arbeitsdaten\"

/*****************************************/
/* Selection Gruppierungs and Gliederungs-Number */
/*****************************************/

#delimit ;
local kreis = "$KREIS" ;
local gruppierung "	999 ";

local gliederung "0 1 2 3 4 5 6 60 61 62 63 65 67 68 70 72 73 74 75 76 77 78 79 84 80 81 82 83 85 86 87 88 89 9";	
#delimit cr

local glied0 0
local glied1 1
local glied2 2
local glied3 3
local glied4 4
local glied5 5
local glied6 6
local glied61 63 65 67 68 
local glied62 60 61 62
local glied7 70 72 73 74 75 76 77
local glied8 80 81 82 83 85 86 87 88 89
local glied9 9
local glied10 78 79 84

local list1
foreach var in `gliederung' {
	local list1 `list1' *x`var'
}

/*****************************************/
/* Load data sets and required variables */
/*****************************************/

use AGS_2007 year `list1' using "${DIR_JHR}\JHR.dta", clear
capture confirm numeric variable AGS_2007
if _rc!=0 {
	destring AGS_2007, replace
}
ren AGS_2007 id_AGS
local testlist id_AGS year
foreach var in `gruppierung' {
	local testlist `testlist' EF`var'x*
}
quietly ds `testlist'
local testlist2 `r(varlist)'
keep `testlist2'

/*****************************************/
/* Include county expenditures allocated using population */
/*****************************************/

if ("`kreis'"=="ja") {
	gen kreis = int(id_AGS / 1000)

	preserve
	use kreis year `list1' using "${DIR_JHR}\JHR_KREISE", clear
	local testlist kreis year
	foreach var in `gruppierung' {
		local testlist `testlist' KREIS_EF`var'x*
	}
	quietly ds `testlist'
	local testlist2 `r(varlist)'
	keep `testlist2'
	tempfile kreisausgaben
	save "{DIR_JHR}\`kreisausgaben'", replace
	restore
	merge m:1 kreis year using "${DIR_JHR}\`kreisausgaben'", keep(1 3) nogenerate
	drop kreis
	merge 1:1 id_AGS year using "${DIR_JHR}\POP", keep(1 3) nogenerate ///
	keepusing(pop)
		
	gen id_kreis=int(id_AGS/1000)
	bys id_kreis year: egen pop_kreis = sum(pop)
	
	ds EF*
	foreach var in `r(varlist)' {
		ren `var' old_`var'
		capture replace KREIS_`var' = KREIS_`var'*(pop / pop_kreis)
		if _rc==0 {
			capture egen `var'=rowtotal(old_`var' KREIS_`var')
			replace `var'=. if (old_`var'==. & KREIS_`var'==.) | pop == .
			drop old_`var' KREIS_`var'
		}
		if _rc!=0 {
			egen `var'=rowtotal(old_`var')
			replace `var'=. if (old_`var'==.) | pop == .
			drop old_`var'
		}
	}

	drop pop pop_kreis
}
if ("`kreis'"=="nein") {
	capture drop KREIS_*
}

/*****************************************/
/* Create expenditure variables */
/*****************************************/

local ll
foreach var in `glied0' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_admin = rowtotal(`ll')
replace exp_admin = . if help == 0 
label var exp_admin "Administration Exp."

local ll
foreach var in `glied1' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_security = rowtotal(`ll')
replace exp_security = . if help == 0 
label var exp_security "Security Exp."

local ll
foreach var in `glied2' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_schools = rowtotal(`ll')
replace exp_schools = . if help == 0 
label var exp_schools "School Exp."

local ll
foreach var in `glied3' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_culture = rowtotal(`ll')
replace exp_culture = . if help == 0 
label var exp_culture "Culture Exp."

local ll
foreach var in `glied4' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_social = rowtotal(`ll')
replace exp_social = . if help == 0 
label var exp_social "Social Exp."

local ll
foreach var in `glied5' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_recreation = rowtotal(`ll')
replace exp_recreation = . if help == 0 
label var exp_recreation "Recreation Exp."

local ll
foreach var in `glied6' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_bau = rowtotal(`ll')
replace exp_bau = . if help == 0 
label var exp_bau "Streets Exp"


local ll
foreach var in `glied61' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_traffic = rowtotal(`ll')
replace exp_traffic = . if help == 0 
label var exp_traffic "Streets (narrow) Exp."


local ll
foreach var in `glied62' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_housing = rowtotal(`ll')
replace exp_housing = . if help == 0 
label var exp_housing "Housing Exp."

local ll
foreach var in `glied7' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_public = rowtotal(`ll')
replace exp_public = . if help == 0 
label var exp_public "Public Facilities Exp."

local ll
foreach var in `glied8' {
  local ll `ll' *x`var'
}
capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_public_com = rowtotal(`ll')
replace exp_public_com = . if help == 0 
label var exp_public_com "Public Companies Exp."

local ll
foreach var in `glied9' {
  local ll `ll' *x`var'
}

capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_finanz = rowtotal(`ll')
replace exp_finanz = . if help == 0 
label var exp_finanz "Financial Exp."


local ll
foreach var in `glied10' {
  local ll `ll' *x`var'
}

capture drop help
gen help=0
quietly ds `ll'
local ll `r(varlist)'
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen exp_econ_promo = rowtotal(`ll')
replace exp_econ_promo = . if help == 0 
label var exp_econ_promo "Economic Promotion Epx."

local list2 exp_*
keep id_AGS year `list2'

local var exp_admin exp_security exp_schools exp_culture exp_social exp_recreation  exp_bau exp_traffic exp_housing exp_public_com exp_finanz exp_econ_promo exp_public

foreach var in `var' {

rename `var' `var'_all

}

/*****************************************/
/* Save data set*/
/*****************************************/

save "${DIR}/data/JHR_kategorien_prep_all.dta", replace
