
/* 1c_grants: This do-file prepares the grant variables */

clear
clear all
set more off

/*****************************************/
/* Globals */
/*****************************************/

/* working folder*/
global DIR ""

/* folder Jahresrechnungsstatistik */
global DIR_JHR ""

/*****************************************/
/* Selection Gruppierungs and Gliederungs-Number */
/*****************************************/

tempfile helpfile

#delimit ;
local kreis = "$KREIS" ;
local gruppierung "	360
			361 
			06
			05
			04
			17
			36 ";

local gliederung "	10 
			11 
			13 
			16
			21 
			22 
			23 
			27 
			28
			31
			32
			33
			34
			35
			36
			43
			451
			452
			454
			460
			461
			463
			464
			465
			467
			468
			47
			55
			56
			57
			58
			59
			86
			63
			65
			67
			68
			82
			60
			61
			62
			78 79 84 
			1
			2
			3
			4
			5
			6
			7
			8
			9 ";	
#delimit cr

local list1
foreach var in `gliederung' {
	local list1 `list1' *x`var'
}


/*****************************************/
/* Load data sets and required variables */
/*****************************************/

use AGS_2007 year `list1' using "${DIR_JHR}\JHR.dta", clear
capture confirm numeric variable AGS_2007
if _rc!=0 {
	destring AGS_2007, replace
}
ren AGS_2007 id_AGS
local testlist id_AGS year
foreach var in `gruppierung' {
	local testlist `testlist' *EF`var'x*
}

quietly ds `testlist'
local testlist2 `r(varlist)'
keep `testlist2'

/*****************************************/
/* Include county grants allocated using population */
/*****************************************/

if ("`kreis'"=="ja") {
	gen kreis = int(id_AGS / 1000)

	save "`helpfile'", replace
	use kreis year `list1' using "${DIR_JHR}\JHR_KREISE", clear
	local testlist kreis year
	foreach var in `gruppierung' {
		local testlist `testlist' KREIS_EF`var'x*
	}
	quietly ds `testlist'
	local testlist2 `r(varlist)'
	keep `testlist2'
	tempfile kreisausgaben
	save "{DIR_JHR}\`kreisausgaben'", replace
	use "`helpfile'", clear
	merge m:1 kreis year using "${DIR_JHR}\`kreisausgaben'", keep(1 3) nogenerate
	drop kreis
	merge 1:1 id_AGS year using "${DIR_JHR}\POP", keep(1 3) nogenerate ///
	keepusing(pop)
	
	gen id_kreis=int(id_AGS/1000)
	bys id_kreis year: egen pop_kreis = sum(pop)
	
	ds EF*
	foreach var in `r(varlist)' {
		ren `var' old_`var'
		capture replace KREIS_`var' = KREIS_`var'*(pop / pop_kreis)
		if _rc==0 {
			capture egen `var'=rowtotal(old_`var' KREIS_`var')
			replace `var'=. if (old_`var'==. & KREIS_`var'==.) | pop == .
			drop old_`var' KREIS_`var'
		}
		if _rc!=0 {
			egen `var'=rowtotal(old_`var')
			replace `var'=. if (old_`var'==.) | pop == .
			drop old_`var'
		}
	}

	drop pop pop_kreis
}
if ("`kreis'"=="nein") {
	capture drop KREIS_*
}

/*****************************************/
/* Create grant variables */
/*****************************************/

quietly ds EF04x9
local ll `r(varlist)'
capture drop help
gen help=0
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen zuw_schluessel = rowtotal(`ll')
replace zuw_schluessel = . if help == 0 
label var zuw_schluessel "Grants based on needs "
drop EF04x*

quietly ds EF05x9
local ll `r(varlist)'
capture drop help
gen help=0
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen zuw_bedarf = rowtotal(`ll')
replace zuw_bedarf = . if help == 0 
label var zuw_bedarf "Grants based on needs vs fiscal capacity"
drop EF05x*

quietly ds EF06x1 EF06x2 EF06x4 EF06x5 EF06x6 EF06x7 EF06x8 EF06x9
local ll `r(varlist)'
capture drop help
gen help=0
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen zuw_allg = rowtotal(`ll')
replace zuw_allg = . if help == 0 
label var zuw_allg "General Grants"
drop EF06x*

quietly ds EF17x1 EF17x2 EF17x3 EF17x4 EF17x5 EF17x6 EF17x7 EF17x8 EF17x9
local ll `r(varlist)'
capture drop help
gen help=0
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen zuw_lauf_zwecke = rowtotal(`ll')
replace zuw_lauf_zwecke = . if help == 0 
label var zuw_lauf_zwecke "Grants Current Expenditures"
drop EF17x*

quietly ds EF36x1 EF36x2 EF36x3 EF36x4 EF36x5 EF36x6 EF36x7 EF36x8 EF36x9
local ll `r(varlist)'
capture drop help
gen help=0
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen zuw_investitionen = rowtotal(`ll')
replace zuw_investitionen = . if help == 0 
label var zuw_investitionen "Grants Investment"
drop EF36x*

quietly ds *x1 *x2 *x3 *x4 *x5 *x6 *x7 *x8 *x9
local ll `r(varlist)'
capture drop help
gen help=0
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen zuw_overall = rowtotal(`ll')
replace zuw_overall = . if help == 0 
label var zuw_overall "Grants Total"

quietly ds *x10 *x11 *x13 *x16
local ll `r(varlist)'
capture drop help
gen help=0
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen zuw_security = rowtotal(`ll')
replace zuw_security = . if help == 0 
label var zuw_security "Grants Security"

quietly ds *x21 *x22 *x23 *x27 *x28
local ll `r(varlist)'
capture drop help
gen help=0
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen zuw_schools = rowtotal(`ll')
replace zuw_schools = . if help == 0 
label var zuw_schools "Grants Schools"

quietly ds *x31 *x32 *x33 *x34 *x35 *x36
local ll `r(varlist)'
capture drop help
gen help=0
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen zuw_culture = rowtotal(`ll')
replace zuw_culture = . if help == 0 
label var zuw_culture "Grants Culture"

quietly ds *x43 *x451 *x452 *x454 *x460 *x461 *x463 *x464 *x465 *x467 *x468 *x47
local ll `r(varlist)'
capture drop help
gen help=0
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen zuw_social = rowtotal(`ll')
replace zuw_social = . if help == 0 
label var zuw_social "Grants Social"

quietly ds *x55 *x56 *x57 *x58 *x59 *x86
local ll `r(varlist)'
capture drop help
gen help=0
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen zuw_recreation = rowtotal(`ll')
replace zuw_recreation = . if help == 0 
label var zuw_recreation "Grants Recreation"

quietly ds *x63 *x65 *x67 *x68 *x82
local ll `r(varlist)'
capture drop help
gen help=0
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen zuw_traffic = rowtotal(`ll')
replace zuw_traffic = . if help == 0 
label var zuw_traffic "Grants Streets"

quietly ds *x60 *x61 *x62
local ll `r(varlist)'
capture drop help
gen help=0
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen zuw_housing = rowtotal(`ll')
replace zuw_housing = . if help == 0 
label var zuw_housing "Grants Housing"

quietly ds *x78 *x79 *x84
local ll `r(varlist)'
capture drop help
gen help=0
foreach var in `ll' {
	replace help=1 if `var'!=.
}
egen zuw_econ_promo = rowtotal(`ll')
replace zuw_econ_promo = . if help == 0 
label var zuw_econ_promo "Grant Economic Promotion"

local list2 zuw_*
keep id_AGS year `list2'

/*****************************************/
/* Save data set*/
/*****************************************/

save "${DIR}/data/JHR_zuweisungen_prep.dta", replace
