
/* 1d_sample: This do-files generates the estimation sample. 
In a first step all relevant data sets are merged and variables are generated. 
In a second step the two panels (A and B) are formed */

clear
clear all
set more off


/*****************************************/
/* Globals */
/*****************************************/

/* working folder */
global DIR "F:\Users\msimmler\Desktop\Partisan Replication Files\"

/* folder Jahresrechnungsstatistik */
global DIR_JHR ""

/* output */
global TABLES "$DIR\tables\"


/******************************/
/******************************/
/******************************/
/* 1 Step: Matching different data sources */
/******************************/
/******************************/
/******************************/


/* Muncipality data Statistik Lokal */
use "$DIR/data/municipality_data.dta", replace

/* Voluntary Expenditures - prepared with 1a */
merge 1:1 id_AGS year using "${DIR_JHR}\JHR_kategorien_prep.dta"
drop if _merge == 2
drop _merge

/* Voluntary and Mandatory Expenditures - prepared with 1b  */
merge 1:1 id_AGS year using "${DIR_JHR}\JHR_kategorien_prep_all.dta"
drop if _merge == 2
drop _merge

/* Grants - prepared with 1c  */
merge 1:1 id_AGS year using "${DIR_JHR}\JHR_zuweisungen_prep.dta" 
drop if _merge == 2
drop _merge

/* Election Data */
merge 1:1 id_AGS year using  "${DIR}\data\Wahlen_1994-2007_AGS2007.dta"
drop if _merge == 2

/* Panel Dimension */
xtset id_AGS year

/* Up to 2006 */
drop if year > 2006

/* Only West Germany */
drop if Bundesland > 10


/***********************************/
/***********************************/
/* Preparation Spending Variables */
/***********************************/
/***********************************/

/* Debt the same for voluntary and voluntary + mandatory */
gen exp_finanz = exp_finanz_all
gen ln_exp_finanz_all = log(exp_finanz)

/* Real expenditures = Overall expenditures less financial expenditures */
capture drop exp_real
gen exp_real = exp_overall - exp_finanz

capture drop ln_exp_real_all
gen ln_exp_real_all = log(exp_real)

capture drop ln_exp_overall
gen ln_exp_overall = log(exp_overall)

capture drop ln_rev_overall
gen ln_rev_overall = log(rev_overall)

/* Expenditure Shares: Subcategories */

local var exp_admin exp_security exp_schools exp_culture exp_social exp_recreation exp_bau exp_traffic exp_housing exp_public_com exp_public exp_econ_promo 

foreach var in `var' {

gen s_`var'_sp = (`var' / exp_real) * 100
gen s_`var'_all = (`var'_all / exp_real) * 100

}

/* Expenditure Shares: Broader Categories */

gen s_exp_general_all = s_exp_admin_all + s_exp_security_all + s_exp_public_com_all
gen s_exp_people_all = s_exp_schools_all + s_exp_recreation_all + s_exp_social_all
gen s_exp_infra_all = s_exp_bau_all + s_exp_econ_promo_all+ s_exp_public_all

gen s_exp_general_sp = s_exp_admin_sp + s_exp_security_sp
gen s_exp_people_sp = s_exp_schools_sp + s_exp_recreation_sp + s_exp_social_sp
gen s_exp_infra_sp = s_exp_bau_sp + s_exp_econ_promo_sp	+ s_exp_public_sp

/* Voluntary Expenditure Share */
capture drop s_exp_vol
gen s_exp_vol = 100 - s_exp_people_sp - s_exp_culture_sp -  s_exp_infra_sp - s_exp_general_sp


/***********************************/
/***********************************/
/* Control Variables */
/***********************************/
/***********************************/

capture drop ln_besch_wohnort
gen ln_besch_wohnort = ln(besch_wohnort)

capture drop ln_pop_1000
gen ln_pop_1000 = log(pop_1000)

capture drop ln_unempl_kreis
gen ln_unempl_kreis = log(unempl_kreis)

capture drop ln_kreis_debt
gen ln_kreis_debt = log(KREIS_debt)


/* Lag Control Variables and Replace Missing Values */
/* No information on employment and debt for early years - replace with first year available */

local var ln_KREIS_debt  ln_unempl_kreis  ln_pop_1000 ln_besch_wohnort pop_u20 pop_o65 

foreach var in `var' {

replace `var' = F.`var' if `var' == .
replace `var' = F.`var' if `var' == .
replace `var' = F.`var' if `var' == .
replace `var' = F.`var' if `var' == .
replace `var' = F.`var' if `var' == .
replace `var' = F.`var' if `var' == .

gen L_`var' = L.`var'
replace L_`var' = `var' if L.`var' == .

}


/***********************************/
/***********************************/
/* Grant Data */
/***********************************/
/***********************************/

gen zuw_people = zuw_schools + zuw_social + zuw_recreation
gen zuw_infra = zuw_traffic + zuw_housing + zuw_econ_promo
gen zuw_general = zuw_security

local var zuw_general zuw_schluessel zuw_infra zuw_people zuw_overall zuw_security zuw_schools zuw_culture zuw_social zuw_recreation zuw_traffic zuw_housing zuw_econ_promo

foreach var in `var' {

replace `var' = 0 if `var' == . | `var' < 0
gen l_`var' = log(`var' +1)

}

/*****************************************/
/*****************************************/
/* Election Data */
/*****************************************/
/*****************************************/

rename andere_kom other_kom

local var spd union gruene fdp linke other

foreach var in `var' {

replace share_`var' = `var'_kom/total_seats_kom if total_seats_kom != .
replace share_`var' = 0 if share_`var' == .
gen share_`var'_2 = share_`var'^2

}

gen diff_spd = share_spd - 0.5

rename majority_spd majority_spd2
rename majority_no majority_no2
rename majority_left majority_left2
rename majority_union majority_union2
rename majority_other majority_other2
rename majority_right majority_right2

gen majority_spd = share_spd > 0.5 & share_spd != . & union_kom != .
gen majority_union = share_union > 0.5 & share_union != . & share_spd != . 
gen majority_left = (share_spd + share_gruene + share_linke) > 0.5 & share_spd != .
gen majority_right = (share_union + share_fdp) > 0.5 & share_union != .
gen majority_other = share_other > 0.5 & share_other != .
gen majority_no = (majority_left == 0 & majority_right == 0 & majority_other == 0)

sort id_AGS year 

save "${DIR}\data\sample.dta", replace


/*****************************************/
/****************************************/
/****************************************/
/* 2. Step Forming Panel A and B */
/****************************************/
/****************************************/
/*****************************************/

/****************************************/
/* Number Election Periods */
/****************************************/

use "$DIR\data\sample.dta", replace

drop if election_period == .

gen neu =1 
collapse (max) neu, by(election_period id_AGS)

sort id_AGS election_period
bysort id_AGS: gen wahlperiode = _n

drop if wahlperiode == .

xtset id_AGS wahlperiode

bysort id_AGS: egen max_wahlperiode = max(wahlperiode)

save "$DIR\data\wahlperiode.dta", replace


/****************************************/
* Save Consecutive Election Period Data set */ 
/****************************************/

use "$DIR\data\sample.dta", replace

drop _merge
merge n:1 id_AGS election_period using  "$DIR\data\wahlperiode.dta"
keep if _merge == 3

drop if year > 2006

bysort id_AGS election_period: gen anzahl_jahre = _N
/* at least 3 year */
drop if anzahl_jahre < 3

/* save election period 1 and 2 */
preserve
keep if (wahlperiode == 1 | wahlperiode == 2) & max_wahlperiode >= 2
gen double id_AGS_neu = 100000000 + id_AGS
save "$DIR\data\wahlperiode1u2.dta", replace
restore

/* save election period 2 and 3 */
preserve
keep if (wahlperiode == 2 | wahlperiode == 3) & max_wahlperiode >= 3
gen double id_AGS_neu = 200000000 + id_AGS
save "$DIR\data\wahlperiode2u3.dta", replace
restore

/* save election period 3 and 4 */
keep if (wahlperiode == 3 | wahlperiode == 4) & max_wahlperiode >= 4
gen double id_AGS_neu = 300000000 + id_AGS

save "$DIR\data\wahlperiode3u4.dta", replace


/****************************************/
/* Combine Consecutive Election Periods Data sets */
/****************************************/

use "$DIR\data\wahlperiode1u2.dta", replace

append using "$DIR\data\wahlperiode2u3.dta"

append using "$DIR\data\wahlperiode3u4.dta"

/* Rename Unique Identifier and Consecutive Election Period Unique Identifier */
rename id_AGS id_AGS_unique
rename id_AGS_neu id_AGS

xtset id_AGS year

save "$DIR/\data\wahlperioden_datensatz.dta", replace


/****************************************/
/****************************************/
/* Selection Sample Panel A */
/****************************************/
/****************************************/

use "$DIR/\data\wahlperioden_datensatz.dta", replace

/* Collapse */

collapse (max)  majority_*, by(election_period id_AGS)

sort id_AGS election_period
bysort id_AGS: gen lfd = _n

xtset id_AGS lfd

/* Abwahl */
gen d_spd = d.majority_union
drop if d_spd == -1
drop d_spd

gen cdu_sample = 1 if ((L.majority_spd == 1) & majority_union == 1) 
replace cdu_sample = 1 if F.cdu_sample == 1

bysort id_AGS: egen m_cdu_sample = max(cdu_sample)

/* Kontrollgruppe */

replace cdu_sample = 1 if (L.majority_spd == 1 & majority_spd == 1) & m_cdu_sample != 1
replace cdu_sample = 1 if F.cdu_sample == 1 & m_cdu_sample != 1

keep if cdu_sample == 1

save "$DIR/\data\union_sample_electionperiods.dta", replace

/* Match Panel A Jurisdictions to Estimation Sample */

use "$DIR/\data\wahlperioden_datensatz.dta", replace

drop _merge
merge n:1 id_AGS election_period using "$DIR/data/union_sample_electionperiods.dta"
keep if _merge == 3
drop _merge

sort id_AGS year
gen d_majority = d.majority_union
bysort id_AGS: egen treatment = max(d_majority)

/* Drop observations with only one election period */
bysort id_AGS: egen min2wahl = sd(election_period)
drop if min2wahl == 0 & treatment == 0
drop min2wahl

/************************************/
/* Variables last Election period */
/************************************/

sort id_AGS election_period year

bysort id_AGS: egen min_wahl = min(election_period)
bysort id_AGS election_period: gen nr = _n
bysort id_AGS election_period: egen max_nr = max(nr)

tab min_wahl, gen(d_min_wahl_)

#delimit ;
local endlist " s_exp_vol
							  ln_exp_real_all
							  ln_exp_finanz_all
							  rate_tradetax
							  s_exp_general_sp
							  s_exp_people_sp 
							  s_exp_culture_sp 
							  s_exp_infra_sp
							  
							  ";
#delimit cr

global cemvar
foreach var in `endlist' {
  capture drop help
	sort id_AGS year
	xtset id_AGS year 
	gen end_`var'_h = `var' if election_period == min_wahl & nr == max_nr
	bysort id_AGS: egen end_`var' = mean(end_`var'_h)
	gen end_d_`var'_h = d.`var' if election_period == min_wahl & nr == max_nr
	bysort id_AGS: egen end_d_`var' = mean(end_d_`var'_h)
	gen end_d2_`var'_h = `var' - L2.`var' if election_period == min_wahl & nr == max_nr
	bysort id_AGS: egen end_d2_`var' = mean(end_d2_`var'_h)
	capture drop help
	global cemvar ${cemvar} end_`var'
}


/* Sample Selection */

/* Excluding kreisfreie Staedte */
capture drop help help2
gen help = id_AGS
tostring help, replace
gen help2 = substr(help, strlen(help)-2, strlen(help))
gen krsf_stadt = (help2 == "000")
drop help help2
drop if krsf_stadt == 1

/* Min and Max Population */
bys id_AGS: egen m_pop = mean(pop)
drop if m_pop < 1000 | m_pop > 50000

/* Abspeichern */
save "${DIR}/data/PanelA.dta", replace


/****************************************/
/****************************************/
/* Selection Sample Panel B */
/****************************************/
/****************************************/

use "$DIR\data\wahlperioden_datensatz.dta", replace

/* Collapse */

collapse (max)  majority_*, by(election_period id_AGS)

sort id_AGS election_period
bysort id_AGS: gen lfd = _n

xtset id_AGS lfd

/* Abwahl */
gen d_spd = d.majority_spd
drop if d_spd == -1
drop d_spd

/* Treatment */
gen spd_sample = 1 if ((L.majority_union == 1) & majority_spd == 1) 
replace spd_sample = 1 if F.spd_sample == 1
bysort id_AGS: egen m_spd_sample = max(spd_sample)

/* Control */
replace spd_sample = 1 if (L.majority_union == 1 & majority_union == 1) & m_spd_sample != 1
replace spd_sample = 1 if F.spd_sample == 1 & m_spd_sample != 1

/* Selection */
keep if spd_sample == 1

save "$DIR\data\spd_sample_electionperiods.dta", replace

use "$DIR\data\wahlperioden_datensatz.dta", replace

drop _merge
merge n:1 id_AGS election_period using "$DIR\data\spd_sample_electionperiods.dta"
keep if _merge == 3
drop _merge

sort id_AGS year
gen d_majority = d.majority_spd
bysort id_AGS: egen treatment = max(d_majority)

/* Drop observations with only one election period */
bysort id_AGS: egen min2wahl = sd(election_period)
drop if min2wahl == 0 & treatment == 0
drop min2wahl

/************************************/
/* Variables last Election period */
/************************************/

sort id_AGS election_period year

bysort id_AGS: egen min_wahl = min(election_period)
bysort id_AGS election_period: gen nr = _n
bysort id_AGS election_period: egen max_nr = max(nr)

tab min_wahl, gen(d_min_wahl_)

#delimit ;
local endlist " s_exp_vol
							  ln_exp_real_all
							  ln_exp_finanz_all
							  rate_tradetax
							  s_exp_general_sp
							  s_exp_people_sp 
							  s_exp_culture_sp 
							  s_exp_infra_sp
							  
							  ";
#delimit cr

global cemvar
foreach var in `endlist' {
  capture drop help
	sort id_AGS year
	xtset id_AGS year 
	gen end_`var'_h = `var' if election_period == min_wahl & nr == max_nr
	bysort id_AGS: egen end_`var' = mean(end_`var'_h)
	gen end_d_`var'_h = d.`var' if election_period == min_wahl & nr == max_nr
	bysort id_AGS: egen end_d_`var' = mean(end_d_`var'_h)
	gen end_d2_`var'_h = `var' - L2.`var' if election_period == min_wahl & nr == max_nr
	bysort id_AGS: egen end_d2_`var' = mean(end_d2_`var'_h)
	capture drop help
	global cemvar ${cemvar} end_`var'
}


/* Sample Selection */

/* Excluding kreisfreie Staedte */
capture drop help help2
gen help = id_AGS
tostring help, replace
gen help2 = substr(help, strlen(help)-2, strlen(help))
gen krsf_stadt = (help2 == "000")
drop help help2
drop if krsf_stadt == 1

/* Min and Max Population */
bys id_AGS: egen m_pop = mean(pop)
drop if m_pop < 1000 | m_pop > 50000

/* Abspeichern */
save "${DIR}/data/PanelB.dta", replace









