
/* 2_instrument: This do-file generates the excluded instruments. 
Data on the Sonntagsfrage is matched and election date exogenous shifts 
in combintation with the seat share in the first year are used 
to predict seat share for SPD and Union */

clear
clear all
set more off

/******************************/
* Globals
/******************************/

/* working folder*/
global DIR ""

/* output */
global TABLES "$DIR\tables\"

/******************************/
/* Load Estimation Sample */
/******************************/

use "${DIR}\data\sample.dta", replace

/* Official Election Months */

gen monat =3 if year == 1994 & Bundesland == 1
replace monat =3 if year == 1998 & Bundesland == 1
replace monat =3 if year == 2003 & Bundesland == 1

replace monat =9 if year == 1991 & Bundesland == 3
replace monat =9 if year == 1996 & Bundesland == 3
replace monat =9 if year == 2001 & Bundesland == 3
replace monat =9 if year == 2006 & Bundesland == 3

replace monat =10 if year == 1994 & Bundesland == 5
replace monat =9 if year == 1999 & Bundesland == 5
replace monat =9 if year == 2004 & Bundesland == 5

replace monat =3 if year == 1993 & Bundesland == 6
replace monat =3 if year == 1997 & Bundesland == 6
replace monat =3 if year == 2001 & Bundesland == 6
replace monat =3 if year == 2006 & Bundesland == 6

replace monat =6 if year == 1994 & Bundesland == 7
replace monat =6 if year == 1999 & Bundesland == 7
replace monat =6 if year == 2004 & Bundesland == 7

replace monat =6 if year == 1994 & Bundesland == 8
replace monat =10 if year == 1999 & Bundesland == 8
replace monat =6 if year == 2004 & Bundesland == 8

replace monat =3 if year == 1996 & Bundesland == 9
replace monat =3 if year == 2002 & Bundesland == 9

replace monat =6 if year == 1994 & Bundesland == 10
replace monat =6 if year == 1999 & Bundesland == 10
replace monat =6 if year == 2004 & Bundesland == 10

/* Match Data on Sonntagsfrage */
capture drop _merge
merge n:1 monat year using "${DIR}\data\sonntagsfrage.dta" 
drop if _merge == 2
drop _merge

/* Fix Sonntagsfrage-Information over Election Period */

local var cdu_fc spd_fc 

sort id_AGS year

foreach var in `var' {

replace `var' = L.`var' if `var' == .
replace `var' = L.`var' if `var' == .
replace `var' = L.`var' if `var' == .
replace `var' = L.`var' if `var' == .

replace `var' = F.`var' if `var' == .
replace `var' = F.`var' if `var' == .
replace `var' = F.`var' if `var' == .
replace `var' = F.`var' if `var' == .

replace `var' = 0 if `var' == .

}


/* Construction Instrument */
sort id_AGS year
bysort id_AGS: gen anzahl = _n

/* Vote Share first year */
gen start_spd = share_spd if anzahl== 1
gen start_union = share_union if anzahl== 1

sort id_AGS year

bysort id_AGS: egen m_start_spd = max(start_spd)
bysort id_AGS: egen m_start_union = max(start_union)

/* In case of zero vote share assume 0.25 */
replace m_start_spd = 0.25 if m_start_spd == 0
replace m_start_union= 0.25 if m_start_union == 0

/* Predict Seat Share Change using Sonntagsfrage Information */
gen d_share_spd1 = d.spd_fc/L.spd_fc
gen d_share_union1 = d.cdu_fc/L.cdu_fc

/* Construct Predicted Vote Share of Sample Period */

/* First Year = Observed First Year */
sort id_AGS year

gen iv_spd1 = m_start_spd
gen iv_union1 = m_start_union

/* All other years .... added over time */

forvalue i = 2(1)13 {

replace iv_spd1 = L.iv_spd1 * (1+ d_share_spd1) if anzahl == `i'
replace iv_union1 = L.iv_union1 * (1+ d_share_union1) if anzahl == `i'

}

keep id_AGS year iv_spd1 iv_union 
rename id_AGS id_AGS_unique

/* Save */
save  "${DIR}\data\instrument.dta", replace


