
/* 3_estimation_iv. This do-file includes the matching and 
produces the descriptive statistics and the estimation results 
for the main part of the paper.  */

clear
clear all
set more off

/******************************/
/* Globals */
/******************************/

/* working folder*/
global DIR ""

/* output */
global TABLES "$DIR\tables\"


/******************************/
/* Combine Panel A and B */
/******************************/

/* Panel B */
use "${DIR}\data\PanelB.dta", replace
gen pre = 0

/* Panel A */
append using "${DIR}\data\PanelA.dta"
replace pre = 1 if pre == .

/* Match Instrument */
capture drop _merge
merge n:1 id_AGS_unique year using  "${DIR}\data\instrument.dta"
drop if _merge == 2

/* All relevant variables are observed */
foreach var in ln_exp_overall ln_KREIS_debt  ln_unempl_kreis  ln_pop_1000 ln_besch_wohnort pop_u20 pop_o65 end_d2_rate_tradetax end_d2_ln_exp_real_all end_d2_ln_exp_finanz_all end_d2_s_exp_general_sp end_d2_s_exp_people_sp end_d2_s_exp_culture_sp end_d2_s_exp_infra_sp {

drop if `var' == .

} 

/* Election Year */
bys id_AGS: egen treatment_start2 = min(year)

/*********************/
/* Labels */
/*********************/

capture noisily label var majority_spd "SPD"

capture noisily label var exp_overall "Overall expenditure in million euro"
capture noisily label var rev_overall "Overall revenue in million euro"
capture noisily label var exp_real "Real exp. in million euro"
capture noisily label var exp_finanz "Financial exp. in million euro "
capture noisily label var s_exp_vol "Overall voluntary public good spending \%"

capture noisily label var pop_1000 "Population in 1000"
capture noisily label var pop_u20 "Share Population under 20"
capture noisily label var pop_o65 "Share Population over 65"
capture noisily label var unempl_kreis "Unemployment Rate (County)"

capture noisily label var s_exp_general_all "General Public Good Spending in \%"
capture noisily label var s_exp_admin_all "Administration Spending in \%"
capture noisily label var s_exp_security_all "Security Spending in \%"
capture noisily label var s_exp_public_com_all "Public Firms Spending in \%"

capture noisily label var s_exp_people_all "People Public Good Spending in \%"
capture noisily label var s_exp_schools_all "School Spending in \%"
capture noisily label var s_exp_recreation_all "Recreation Spending in \%"
capture noisily label var s_exp_social_all "Social Spending in \%"
capture noisily label var s_exp_culture_all "Culture Spending in \%"
capture noisily label var s_exp_infra_all "Infrastructure Spending in \%"
capture noisily label var s_exp_bau_all "Streets Public Good Spending in \%"
capture noisily label var s_exp_public_all "All Public Facility Spending in \%"
capture noisily label var s_exp_econ_promo_all "All Economic Promotion Spending in \%"
			   
capture noisily label var s_exp_people_sp "Voluntary People Public Good Spending in \%"
capture noisily label var s_exp_schools_sp "Voluntary School Spending in \%"
capture noisily label var s_exp_recreation_sp "Voluntary Recreation Spending in \%"
capture noisily label var s_exp_social_sp "Voluntary Social Spending in \%"
capture noisily label var s_exp_culture_sp "Voluntary Culture Spending in \%"
capture noisily label var s_exp_bau_sp "Voluntary Streets Public Good Spending in \%"
capture noisily label var s_exp_public_sp "Voluntary Public Facility Spending in \%"
capture noisily label var s_exp_econ_promo_sp "Voluntary Economic Promotion Spending in \%"

capture noisily label var end_rate_tradetax "Local business tax multiplier"
capture noisily label var end_ln_exp_real_all "(ln) Real expenditures"
capture noisily label var end_ln_exp_finanz_all "(ln) Financial expenditures"
capture noisily label var end_s_exp_vol " Share voluntary expenditures"
capture noisily label var end_s_exp_general_sp " Share general public good expenditures"
capture noisily label var end_s_exp_people_sp " Share people public good expenditures"
capture noisily label var end_s_exp_culture_sp " Share culture expenditures"
capture noisily label var end_s_exp_infra_sp " Share infrastructure expenditures"	 

capture noisily label var end_d2_rate_tradetax "$\delta$ Local business tax multiplier"
capture noisily label var end_d2_ln_exp_real_all "$\delta$ (ln) Real expenditures"
capture noisily label var end_d2_ln_exp_finanz_all "$\delta$ (ln) Financial expenditures"
capture noisily label var end_d2_s_exp_vol "$\delta$ Share voluntary expenditures"
capture noisily label var end_d2_s_exp_general_sp " $\delta$ Share general public good expenditures"
capture noisily label var end_d2_s_exp_people_sp " $\delta$ Share people public good expenditures"
capture noisily label var end_d2_s_exp_culture_sp "$\delta$ Share culture expenditures"
capture noisily label var end_d2_s_exp_infra_sp "$\delta$ Share infrastructure expenditures"	 

/*********************/
/*********************/
/*********************/
/* A. Matching */
/*********************/
/*********************/
/*********************/

/*********************/
/*********************/
/* 1. Baseline */
/*********************/
/*********************/

/*********************/
/* CDU - SPD vs CDU - CDU */
/*********************/

#delimit ;
capture noisily ebalance treatment					
							
					end_d2_rate_tradetax
								
					end_d2_ln_exp_real_all 
					
					end_d2_ln_exp_finanz_all 

					end_d2_s_exp_general_sp
					
					end_d2_s_exp_people_sp 
					
					end_d2_s_exp_culture_sp 
					
					end_d2_s_exp_infra_sp

					i.Bundesland 
					
					if treatment_start == year & pre == 0
					
					, gen(weights1)  targets(2 2 2 2 2 2 2 1 1 1 1 1 1 1  ); 

bysort id_AGS: egen w1 = mean(weights1);
#delimit cr

/*********************/
/* SPD - CDU vs SPD - SPD */
/*********************/

#delimit ;
capture noisily ebalance treatment									
									
					end_d2_rate_tradetax
											
					end_d2_ln_exp_real_all 
					
					end_d2_ln_exp_finanz_all 

					end_d2_s_exp_general_sp
					
					end_d2_s_exp_people_sp 
					
					end_d2_s_exp_culture_sp 
					
					end_d2_s_exp_infra_sp
					
					i.Bundesland 
					
					if treatment_start == year & pre == 1
					
					, gen(weights2)  targets(2 2 2 2 2 2 2 1 1 1 1 1 1 ); 

bysort id_AGS: egen w2 = mean(weights2);
#delimit cr

replace w2 = w1 if w2 == .
drop w1 weights1 weights2

rename w2 weight_base


/*********************/
/*********************/
/* 1. Robustness: without state indicator & change */
/*********************/
/*********************/

/*********************/
/* CDU - SPD vs CDU - CDU */
/*********************/

#delimit ;
capture noisily ebalance treatment					
							
					end_d2_rate_tradetax
								
					end_d2_ln_exp_real_all 
					
					end_d2_ln_exp_finanz_all 

					end_d2_s_exp_general_sp
					
					end_d2_s_exp_people_sp 
					
					end_d2_s_exp_culture_sp 
					
					end_d2_s_exp_infra_sp
					
					if treatment_start == year & pre == 0
					
					, gen(weights1)  targets(2 2 2 2 2 2 2 ); 

bysort id_AGS: egen w1 = mean(weights1);
#delimit cr

/*********************/
/* SPD - CDU vs SPD - SPD */
/*********************/

#delimit ;
capture noisily ebalance treatment									
									
					end_d2_rate_tradetax
											
					end_d2_ln_exp_real_all 
					
					end_d2_ln_exp_finanz_all 

					end_d2_s_exp_general_sp
					
					end_d2_s_exp_people_sp 
					
					end_d2_s_exp_culture_sp 
					
					end_d2_s_exp_infra_sp
					
					if treatment_start == year & pre == 1
					
					, gen(weights2)  targets(2 2 2 2 2 2 2 ); 

bysort id_AGS: egen w2 = mean(weights2);
#delimit cr

replace w2 = w1 if w2 == .
drop w1

rename w2 weight_robust1
drop weights1 weights2

/*********************/
/*********************/
/* 2. Robustness: without state indicators & levels and change */
/*********************/
/*********************/

/*********************/
/* CDU - SPD vs CDU - CDU */
/*********************/

#delimit ;
capture noisily ebalance treatment					
								
					end_rate_tradetax
								
					end_ln_exp_real_all 
					
					end_ln_exp_finanz_all

					end_s_exp_general_sp
					
					end_s_exp_people_sp
					
					end_s_exp_culture_sp 
					
					end_s_exp_infra_sp	
					
					end_d2_rate_tradetax
								
					end_d2_ln_exp_real_all 
					
					end_d2_ln_exp_finanz_all

					end_d2_s_exp_general_sp
					
					end_d2_s_exp_people_sp
					
					end_d2_s_exp_culture_sp 
					
					end_d2_s_exp_infra_sp
					
					if treatment_start == year & pre == 0
					
					, gen(weights1)  targets(2 2 2 2 2 2 2 2 2 2 2 2 2 2); 

bysort id_AGS: egen w1 = mean(weights1);
#delimit cr

/*********************/
/* SPD - CDU vs SPD - SPD */
/*********************/

#delimit ;
capture noisily ebalance treatment									
								
					end_rate_tradetax
								
					end_ln_exp_real_all 
					
					end_ln_exp_finanz_all

					end_s_exp_general_sp
					
					end_s_exp_people_sp
					
					end_s_exp_culture_sp 
					
					end_s_exp_infra_sp	
					
					end_d2_rate_tradetax
								
					end_d2_ln_exp_real_all 
					
					end_d2_ln_exp_finanz_all

					end_d2_s_exp_general_sp
					
					end_d2_s_exp_people_sp
					
					end_d2_s_exp_culture_sp 
					
					end_d2_s_exp_infra_sp			
			
					if treatment_start == year & pre == 1
					
					, gen(weights2)  targets(2 2 2 2 2 2 2 2 2 2 2 2 2 2); 

bysort id_AGS: egen w2 = mean(weights2);
#delimit cr

replace w2 = w1 if w2 == .
drop w1 weights1 weights2

rename w2 weight_robust2

/*************************/
/*************************/
/* 3. Robustness: Propensity Score */
/*************************/
/*************************/

/*********************/
/* CDU - SPD vs CDU - CDU */
/*********************/

/* recode state indicator otherwise doesn't run through */

gen State3 = Bundesland == 3
gen State7 = Bundesland == 7

#delimit;
psmatch2 treatment					
						
		end_d2_rate_tradetax
						
		end_d2_ln_exp_real_all
					
		end_d2_ln_exp_finanz_all 

		end_d2_s_exp_general_sp
					
		end_d2_s_exp_people_sp 
					
		end_d2_s_exp_culture_sp 
					
		end_d2_s_exp_infra_sp
		
		State3
		
		State7 
		
		if treatment_start == year & pre == 0, logit kernel;
		
bysort id_AGS: egen w1 = mean(_pscore);
#delimit cr

/*********************/
/* SPD - CDU vs SPD - SPD */
/*********************/

/* recode state indicator otherwise doesn't run through */

gen Bundesland_NEW = Bundesland
replace Bundesland_NEW = 1 if Bundesland == 6

#delimit;
psmatch2 treatment					
						
		end_d2_rate_tradetax
						
		end_d2_ln_exp_real_all 
					
		end_d2_ln_exp_finanz_all 

		end_d2_s_exp_general_sp
					
		end_d2_s_exp_people_sp 
					
		end_d2_s_exp_culture_sp 
					
		end_d2_s_exp_infra_sp
		
		i.Bundesland_NEW 
		
		if treatment_start == year & pre == 1, logit kernel;
		
bysort id_AGS: egen w2 = mean(_pscore);
#delimit cr

replace w2 = w1 if w2 == . & w1 != .
drop w1 

rename w2 weight_robust3

/*********************/
/*********************/
/*********************/
/* B. Instruments  */
/*********************/
/*********************/
/*********************/

gen d_iv_spd1 = iv_spd1 > 0.5
gen d_iv_union1 = iv_union1 > 0.5

gen pre_d_iv_spd1 = (1- pre) * d_iv_spd1 
gen pre_d_iv_union1 = pre * d_iv_union1


/*********************/
/*********************/
/*********************/
/* C. Covariates */
/*********************/
/*********************/
/*********************/

/* squared covariates */
gen L_ln_pop_1000_2 = L_ln_pop_1000^2
gen L_pop_u20_2 =L_pop_u20^2
gen L_pop_o65_2 =L_pop_o65^2
gen L_ln_besch_wohnort_2 = L_ln_besch_wohnort^2
gen L_ln_unempl_kreis_2 = L_ln_unempl_kreis^2
gen L_ln_KREIS_debt_2 = L_ln_KREIS_debt^2

gen l_zuw_overall_2 = l_zuw_overall^2
gen l_zuw_general_2 =l_zuw_general^2
gen l_zuw_people_2 = l_zuw_people^2
gen l_zuw_culture_2 = l_zuw_culture^2
gen l_zuw_infra_2 = l_zuw_infra^2

egen state_year = group(Bundesland year)

/* election-period collapsed estimation */

global depvarlist "ln_exp_real_all ln_exp_finanz_all ln_exp_vol rate_tradetax s_exp_general_sp  s_exp_people_sp s_exp_culture_sp s_exp_infra_sp"
global exo "L_ln_pop_1000 L_pop_u20 L_pop_u20_2 L_pop_o65 L_pop_o65_2 L_ln_besch_wohnort L_ln_besch_wohnort_2 L_ln_unempl_kreis L_ln_unempl_kreis_2 L_ln_KREIS_debt L_ln_KREIS_debt_2 "
global zuw2 "l_zuw_overall l_zuw_people l_zuw_culture  l_zuw_infra "
global zuw "l_zuw_overall l_zuw_security l_zuw_housing l_zuw_recreation l_zuw_social l_zuw_schools l_zuw_culture l_zuw_traffic l_zuw_econ_promo "


* Ausgaben --------------------------------------------------------------------
foreach var in $depvarlist $exo $zuw {
  bys id_AGS election_period: egen diff_`var' = mean(`var')
}

egen state_year2 = group(Bundesland election_period)

bysort id_AGS election_period: gen diff_nr = _n


/*********************/
/*********************/
/*********************/
/* D. Estimation */
/*********************/
/*********************/
/*********************/

global exo "L_ln_pop_1000 L_pop_u20 L_pop_u20_2 L_pop_o65 L_pop_o65_2 L_ln_besch_wohnort L_ln_besch_wohnort_2 L_ln_unempl_kreis L_ln_unempl_kreis_2 L_ln_KREIS_debt L_ln_KREIS_debt_2 "
global zuw "l_zuw_overall l_zuw_security l_zuw_housing l_zuw_recreation l_zuw_social l_zuw_schools l_zuw_culture l_zuw_traffic l_zuw_econ_promo "

global diff_exo "diff_L_ln_pop_1000 diff_L_pop_u20 diff_L_pop_u20_2 diff_L_pop_o65 diff_L_pop_o65_2 diff_L_ln_besch_wohnort diff_L_ln_besch_wohnort_2 diff_L_ln_unempl_kreis diff_L_ln_unempl_kreis_2 diff_L_ln_KREIS_debt diff_L_ln_KREIS_debt_2 "
global diff_zuw "diff_l_zuw_overall diff_l_zuw_security diff_l_zuw_housing diff_l_zuw_recreation diff_l_zuw_social diff_l_zuw_schools diff_l_zuw_culture diff_l_zuw_traffic diff_l_zuw_econ_promo "

/* Main Tables */

forvalue i = 4(1)6 {

	forvalue j = 1(1)3 {

	cap erase "$TABLES/tab`i'_panel`j'.tex"
	cap erase "$TABLES/tab`i'_panel`j'.txt"
	cap erase "$TABLES/tab`i'_panel`j'.xml"

	} 

}

/* Appendix Tables A*/

forvalue i = 5(1)7 {

	forvalue j = 1(1)5 {

	cap erase "$TABLES/tabA`i'_panel`j'.tex"
	cap erase "$TABLES/tabA`i'_panel`j'.txt"
	cap erase "$TABLES/tabA`i'_panel`j'.xml"

	} 

}


/****************************/
/* Main Dependent Variables I */
/* Table 3, A6 and A7 */
/****************************/

local tab1 ln_exp_real_all ln_exp_finanz_all ln_exp_vol rate_tradetax s_exp_general_sp s_exp_people_sp s_exp_culture_sp s_exp_infra_sp

foreach tab1 in `tab1' {

/* Table 4 */

/* IV - weighted */
xi: ivreghdfe  `tab1' (majority_spd = pre_d_iv_spd1 pre_d_iv_union1) $exo $zuw  [aw = weight_base], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tab4_panel1.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes, iv, yes) adds(F-Stat, e(widstat), Hansen, e(jp))

/* Reduced Form CDU -> SPD */
xi: ivreghdfe  `tab1' pre_d_iv_spd1 $exo $zuw if pre == 0 [aw = weight_base], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tab4_panel2.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes, iv, no) 

/* Reduced Form SPD -> CDU */
xi: ivreghdfe  `tab1' pre_d_iv_union1 $exo $zuw  if pre == 1 [aw = weight_base], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tab4_panel3.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes, iv, no) 

/* Table A6 */

/* IV - weighted ohne control */
xi: ivreghdfe  `tab1' (majority_spd = pre_d_iv_spd1 pre_d_iv_union1)  [aw = weight_base], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) 
outreg2 using "$TABLES/tabA6_panel1.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, no, iv, yes) adds(F-Stat, e(widstat), Hansen, e(jp))

/* Collapsed */
xi: ivreghdfe diff_`tab1'   (majority_spd =  pre_d_iv_union1 pre_d_iv_spd1   ) $diff_exo $diff_zuw if diff_nr ==1 [aw = weight_base], robust cluster(id_AGS_unique  election_period ) absorb(state_year2 id_AGS) partial($diff_exo $diff_zuw) 
outreg2 using "$TABLES/tabA6_panel2.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes, iv, yes) adds(F-Stat, e(widstat), Hansen, e(jp))

/* IV - weighted without state only change */
xi: ivreghdfe  `tab1' (majority_spd = pre_d_iv_spd1 pre_d_iv_union1) $exo $zuw  [aw = weight_robust1], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tabA6_panel3.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes, iv, yes) adds(F-Stat, e(widstat), Hansen, e(jp))

/* IV - weighted without state change and level */
xi: ivreghdfe  `tab1' (majority_spd = pre_d_iv_spd1 pre_d_iv_union1) $exo $zuw  [aw = weight_robust2], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tabA6_panel4.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes, iv, yes) adds(F-Stat, e(widstat), Hansen, e(jp))

/* Propensity Score */
xi: ivreghdfe  `tab1' (majority_spd = pre_d_iv_spd1 pre_d_iv_union1) $exo $zuw  [aw = weight_robust3], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tabA6_panel5.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes, iv, yes) adds(F-Stat, e(widstat), Hansen, e(jp))


/* Table A7 */

/* OLS */
xi: ivreghdfe `tab1' majority_spd $exo $zuw  , robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tabA7_panel1.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes, iv, no)

/* OLS - weighted */
xi: ivreghdfe `tab1' majority_spd $exo $zuw   [aw = weight_base], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tabA7_panel2.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes, iv, no)

/* IV */
xi: ivreghdfe  `tab1' (majority_spd = pre_d_iv_spd1 pre_d_iv_union1) $exo $zuw  , robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tabA7_panel3.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes, iv, no) adds(F-Stat, e(widstat), Hansen, e(jp))

/* OLS CDU -> SPD */
xi: ivreghdfe  `tab1' majority_spd $exo $zuw if pre == 0 [aw = weight_base], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tabA7_panel4.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes, iv, no) 

/* OLS SPD -> CDU */
xi: ivreghdfe  `tab1' majority_union $exo $zuw  if pre == 1 [aw = weight_base], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tabA7_panel5.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes, iv, no) 

}


/****************************/
/* Main Dependent Variables II */
/* Table 5 */
/****************************/

local tab2 s_exp_schools_sp  s_exp_recreation_sp s_exp_social_sp s_exp_bau_sp s_exp_public_sp s_exp_econ_promo_sp 

/* Tab 5 */

foreach tab1 in `tab2' {

/* IV - weighted */
xi: ivreghdfe  `tab1' (majority_spd = pre_d_iv_spd1 pre_d_iv_union1) $exo $zuw   [aw = weight_base], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tab5_panel1.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes, iv, no) adds(F-Stat, e(widstat), Hansen, e(jp))

/* Reduced Form CDU -> SPD */
xi: ivreghdfe  `tab1' pre_d_iv_spd1 $exo $zuw if pre == 0 [aw = weight_base], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tab5_panel2.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes, iv, no) 

/* Reduced Form SPD -> CDU */
xi: ivreghdfe  `tab1' pre_d_iv_union1 $exo $zuw if pre == 1 [aw = weight_base], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tab5_panel3.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes, iv, no) 

}				  

/****************************/
/* Main Dependent Variables III */
/* Table 6 */
/****************************/

gen s_exp_general2_all = s_exp_admin_all + s_exp_security_all 

local tab3 s_exp_general_all s_exp_general2_all s_exp_public_com_all  

foreach tab1 in `tab3' {

/* IV - weighted */
xi: ivreghdfe  `tab1' (majority_spd = pre_d_iv_spd1 pre_d_iv_union1) $exo $zuw [aw = weight_base], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tab6_panel1.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes, iv, no) adds(F-Stat, e(widstat), Hansen, e(jp))

/* Reduced Form CDU -> SPD */
xi: ivreghdfe  `tab1' pre_d_iv_spd1 $exo $zuw if pre == 0 [aw = weight_base], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tab6_panel2.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes, iv, no) 

/* Reduced Form SPD -> CDU */
xi: ivreghdfe  `tab1' pre_d_iv_union1 $exo $zuw if pre == 1 [aw = weight_base], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tab6_panel3.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes, iv, no) 

}	

/****************************/
/* Appendix Table  */
/* FirstStage Results Table A5 */
/****************************/

* IV Weighted 
xi: ivreghdfe  majority_spd pre_d_iv_spd1 pre_d_iv_union1 $exo $zuw  [aw = weight_base], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tabA5_panel1.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes)

* IV Weighed ohne Controls

xi: ivreghdfe  majority_spd pre_d_iv_spd1 pre_d_iv_union1  [aw = weight_base], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) 
outreg2 using "$TABLES/tabA5_panel1.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, no)

* IV Weighted Collapsed

xi: ivreghdfe majority_spd pre_d_iv_union1 pre_d_iv_spd1 $diff_exo $diff_zuw if diff_nr ==1 [aw = weight_base], robust cluster(id_AGS_unique  election_period ) absorb(state_year2 id_AGS) partial($diff_exo $diff_zuw)
outreg2 using "$TABLES/tabA5_panel1.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes)

* IV Weighted Ohne State 

xi: ivreghdfe  majority_spd pre_d_iv_spd1 pre_d_iv_union1 $exo $zuw  [aw = weight_robust1], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tabA5_panel1.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes)

* IV Weighted Sample (ohne Levels and ohne State)

xi: ivreghdfe  majority_spd pre_d_iv_spd1 pre_d_iv_union1 $exo $zuw  [aw = weight_robust2], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tabA5_panel1.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes)

* IV Propensity Score
xi: ivreghdfe  majority_spd pre_d_iv_spd1 pre_d_iv_union1 $exo $zuw  [aw = weight_robust3], robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tabA5_panel1.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes)

* IV not weighted 
xi: ivreghdfe  majority_spd pre_d_iv_spd1 pre_d_iv_union1 $exo $zuw  , robust cluster(id_AGS_unique  election_period ) absorb(state_year id_AGS) partial($exo $zuw)
outreg2 using "$TABLES/tabA5_panel1.tex", append dec (4) tex  addtext(municipality FE, yes, State-Yeear FE, yes, controls, yes)


/****************************************/
/****************************************/
/* * Descriptive Statistics  */
/****************************************/
/****************************************/

/****************************************/
/****************************************/
/* Table 2 and 3 */
/****************************************/
/****************************************/
 
/* Scaling */

replace rev_overall_pc = rev_overall / (pop_1000 * 1000)
replace rev_overall_pc = exp_overall / (pop_1000 * 1000)

replace rev_overall = rev_overall / 1000000
replace exp_overall = exp_overall / 1000000
replace exp_vol = exp_vol / 1000000
replace exp_finanz_ms1 = exp_finanz_ms1 / 1000000
replace besch_wohnort = besch_wohnort / 1000

#delimit ;
local dslist " 

			   rev_overall
			   exp_real		 
			   exp_finanz
			   s_exp_vol
			   rate_tradetax
			 
			   pop_1000        
               pop_u20
			   pop_o65
			  
			   besch_wohnort
			   unempl_kreis
			   KREIS_debt_pc
			   
			   s_exp_general_all
			   s_exp_admin_all
			   s_exp_security_all
			   s_exp_public_com_all
			   			   
			   s_exp_people_all
			   s_exp_schools_all
			   s_exp_recreation_all
			   s_exp_social_all
			   
			   s_exp_culture_all
			   
			   s_exp_infra_all
			   s_exp_bau_all
			   s_exp_public_all
			   s_exp_econ_promo_all
			   
			   s_exp_general_sp
			   s_exp_admin_sp
			   s_exp_security_sp
			   s_exp_public_com_sp
			   
			   s_exp_people_sp
			   s_exp_schools_sp
			   s_exp_recreation_sp
			   s_exp_social_sp
			   
			   s_exp_culture_sp
			   
			   s_exp_infra_sp
			   s_exp_bau_sp
			   s_exp_public_sp
			   s_exp_econ_promo_sp		   
			   		   
 ";
		   
#delimit cr

estpost summarize `dslist', d
estimates store sum1

		   
#delimit ;
esttab sum1 using "$TABLES/ds_partisan.tex"
  , replace 
  style(tex)
	booktabs
  title("Descriptive Statistics\label{tab:ds}") 
  label
  varwidth(60)
  cells("mean(fmt(2) label(Mean)) p50(fmt(2) label(Median)) sd(fmt(2) label(Std. Dev.))")   
  nonumbers 
  nonotes
  nodepvars
  nomtitles
  nostar
  substitute(\begin{tabular} "\begin{threeparttable}\scriptsize\begin{tabular}" \end{tabular} "\end{tabular}\begin{tablenotes}\item \textit{Source:} Own data collection and calculations. \textit{Notes:} Calculations are based on a sample with majors for \$`nmun'\$ municipalities and the year 2006.\end{tablenotes}\end{threeparttable}") ;
#delimit cr


/****************************************/
/****************************************/
/* Matching Quality */
/****************************************/
/****************************************/

/****************************************/
/* Baseline Table A1 and A2				*/
/****************************************/

#delimit ;
local dslist " 					
					end_d2_rate_tradetax
					
					end_d2_ln_exp_real_all 
					end_d2_ln_exp_finanz_all

					end_d2_s_exp_general_sp
					end_d2_s_exp_people_sp 
					end_d2_s_exp_culture_sp 
					end_d2_s_exp_infra_sp					   
 ";   
#delimit cr

estpost summarize `dslist' if treatment == 0  & pre == 0, d
estimates store sum1

estpost summarize `dslist' if treatment == 0  & pre == 0 [aw = weight_base], d
estimates store sum2

estpost summarize `dslist' if treatment == 1  & pre == 0 [aw = weight_base], d
estimates store sum3

estpost summarize `dslist' if treatment == 0  & pre == 1, d
estimates store sum4

estpost summarize `dslist' if treatment == 0 & pre == 1 [aw = weight_base], d
estimates store sum5

estpost summarize `dslist' if treatment == 1 & pre == 1 [aw = weight_base], d
estimates store sum6

/* Table A1 */
/* CDU-SPD vs CDU-CDU */

#delimit ;
esttab sum1 sum2 sum3   using "$TABLES/ds_tabA1.tex"
  , replace 
  style(tex)
	booktabs
  title("Descriptive Statistics\label{tab:ds}") 
  label
  varwidth(60)
  cells("mean(fmt(2) label(Mean)) Var(fmt(2) label(Variance))")   
  nonumbers 
  nonotes
  nodepvars
  nomtitles
  nostar
  substitute(\begin{tabular} "\begin{threeparttable}\scriptsize\begin{tabular}" \end{tabular} "\end{tabular}\begin{tablenotes}\item \textit{Source:} Own data collection and calculations. \textit{Notes:} Calculations are based on a sample with majors for \$`nmun'\$ municipalities and the year 2006.\end{tablenotes}\end{threeparttable}") ;
#delimit cr

/* Testing for Differences */
/* without control variables */
ivreghdfe end_d2_rate_tradetax treatment if pre == 0  [aw = weight_base], robust cluster(id_AGS_unique election_period)
eststo mo1
ivreghdfe end_d2_ln_exp_real_all treatment if pre == 0 [aw = weight_base], robust cluster(id_AGS_unique election_period)
eststo mo2
ivreghdfe end_d2_ln_exp_finanz_all treatment if pre == 0 [aw = weight_base], robust cluster(id_AGS_unique election_period)
eststo mo3
ivreghdfe end_d2_s_exp_general_sp treatment if pre == 0 [aw = weight_base], robust cluster(id_AGS_unique election_period)
eststo mo4
ivreghdfe end_d2_s_exp_people_sp treatment if pre == 0  [aw = weight_base], robust cluster(id_AGS_unique election_period)
eststo mo5
ivreghdfe end_d2_s_exp_culture_sp treatment if pre == 0  [aw = weight_base], robust cluster(id_AGS_unique election_period)
eststo mo6
ivreghdfe end_d2_s_exp_infra_sp treatment if pre == 0 [aw = weight_base], robust cluster(id_AGS_unique election_period)
eststo mo7

esttab mo1 mo2 mo3 mo4 mo5 mo6 mo7, b(3) p

/* with state-year fe */
ivreghdfe end_d2_rate_tradetax treatment if pre == 0 [aw = weight_base], absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo1
ivreghdfe end_d2_ln_exp_real_all treatment if pre == 0 [aw = weight_base] , absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo2
ivreghdfe end_d2_ln_exp_finanz_all treatment if pre == 0 [aw = weight_base] , absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo3
ivreghdfe end_d2_s_exp_general_sp treatment if pre == 0 [aw = weight_base] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo4
ivreghdfe end_d2_s_exp_people_sp treatment if pre == 0  [aw = weight_base] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo5
ivreghdfe end_d2_s_exp_culture_sp treatment if pre == 0  [aw = weight_base] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo6
ivreghdfe end_d2_s_exp_infra_sp treatment if pre == 0 [aw = weight_base] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo7

esttab mo1 mo2 mo3 mo4 mo5 mo6 mo7, b(3) p

/* Table A2 */
/* SPD-CDU vs SPD-SPD */

#delimit ;
esttab sum4 sum5 sum6  using "$TABLES/ds_tabA2.tex"
  , replace 
  style(tex)
	booktabs
  title("Descriptive Statistics\label{tab:ds}") 
  label
  varwidth(60)
  cells("mean(fmt(2) label(Mean)) Var(fmt(2) label(Variance))")   
  nonumbers 
  nonotes
  nodepvars
  nomtitles
  nostar
  substitute(\begin{tabular} "\begin{threeparttable}\scriptsize\begin{tabular}" \end{tabular} "\end{tabular}\begin{tablenotes}\item \textit{Source:} Own data collection and calculations. \textit{Notes:} Calculations are based on a sample with majors for \$`nmun'\$ municipalities and the year 2006.\end{tablenotes}\end{threeparttable}") ;
#delimit cr

/* Testing for Differences */
/* without controls */
ivreghdfe end_d2_rate_tradetax treatment if pre == 1  [aw = weight_base], robust cluster(id_AGS_unique election_period)
eststo mo1
ivreghdfe end_d2_ln_exp_real_all treatment if pre == 1 [aw = weight_base], robust cluster(id_AGS_unique election_period)
eststo mo2
ivreghdfe end_d2_ln_exp_finanz_all treatment if pre == 1 [aw = weight_base], robust cluster(id_AGS_unique election_period)
eststo mo3
ivreghdfe end_d2_s_exp_general_sp treatment if pre == 1 [aw = weight_base], robust cluster(id_AGS_unique election_period)
eststo mo4
ivreghdfe end_d2_s_exp_people_sp treatment if pre == 1  [aw = weight_base], robust cluster(id_AGS_unique election_period)
eststo mo5
ivreghdfe end_d2_s_exp_culture_sp treatment if pre == 1  [aw = weight_base], robust cluster(id_AGS_unique election_period)
eststo mo6
ivreghdfe end_d2_s_exp_infra_sp treatment if pre == 1 [aw = weight_base], robust cluster(id_AGS_unique election_period)
eststo mo7

esttab mo1 mo2 mo3 mo4 mo5 mo6 mo7, b(3) p

/* with state-year */
ivreghdfe end_d2_rate_tradetax treatment if pre == 1 [aw = weight_base], absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo1
ivreghdfe end_d2_ln_exp_real_all treatment if pre == 1 [aw = weight_base] , absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo2
ivreghdfe end_d2_ln_exp_finanz_all treatment if pre == 1 [aw = weight_base] , absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo3
ivreghdfe end_d2_s_exp_general_sp treatment if pre == 1 [aw = weight_base] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo4
ivreghdfe end_d2_s_exp_people_sp treatment if pre == 1  [aw = weight_base] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo5
ivreghdfe end_d2_s_exp_culture_sp treatment if pre == 1  [aw = weight_base] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo6
ivreghdfe end_d2_s_exp_infra_sp treatment if pre == 1 [aw = weight_base] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo7

esttab mo1 mo2 mo3 mo4 mo5 mo6 mo7, b(3) p


/****************************************/
/* Robustness Change + Levels Table A3 and A4	*/
/****************************************/

#delimit ;
local dslist " 					
					end_rate_tradetax
					end_ln_exp_real_all 
					end_ln_exp_finanz_all
					
					end_d2_rate_tradetax
					
					end_d2_ln_exp_real_all 
					end_d2_ln_exp_finanz_all

					end_s_exp_general_sp
					end_s_exp_people_sp 
					end_s_exp_culture_sp 
					end_s_exp_infra_sp
					
					end_d2_s_exp_general_sp
					end_d2_s_exp_people_sp 
					end_d2_s_exp_culture_sp 
					end_d2_s_exp_infra_sp
													   
 ";
			   
#delimit cr

estpost summarize `dslist' if treatment == 0  & pre == 0, d
estimates store sum1

estpost summarize `dslist' if treatment == 0  & pre == 0 [aw = weight_robust2], d
estimates store sum2

estpost summarize `dslist' if treatment == 1  & pre == 0 [aw = weight_robust2], d
estimates store sum3

estpost summarize `dslist' if treatment == 0  & pre == 1, d
estimates store sum4

estpost summarize `dslist' if treatment == 0 & pre == 1 [aw = weight_robust2], d
estimates store sum5

estpost summarize `dslist' if treatment == 1 & pre == 1 [aw = weight_robust2], d
estimates store sum6

/* Table A3 */
/* CDU-SPD vs CDU-CDU */

#delimit ;
esttab sum1 sum2 sum3   using "$TABLES/ds_tabA3.tex"
  , replace 
  style(tex)
	booktabs
  title("Descriptive Statistics\label{tab:ds}") 
  label
  varwidth(60)
  cells("mean(fmt(2) label(Mean)) Var(fmt(2) label(Variance))")   
  nonumbers 
  nonotes
  nodepvars
  nomtitles
  nostar
  substitute(\begin{tabular} "\begin{threeparttable}\scriptsize\begin{tabular}" \end{tabular} "\end{tabular}\begin{tablenotes}\item \textit{Source:} Own data collection and calculations. \textit{Notes:} Calculations are based on a sample with majors for \$`nmun'\$ municipalities and the year 2006.\end{tablenotes}\end{threeparttable}") ;
#delimit cr

/* Testing for Differences */
/* without controls */
ivreghdfe end_rate_tradetax treatment if pre == 0  [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo1
ivreghdfe end_ln_exp_real_all treatment if pre == 0 [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo2
ivreghdfe end_ln_exp_finanz_all treatment if pre == 0 [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo3
ivreghdfe end_d2_rate_tradetax treatment if pre == 0  [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo4
ivreghdfe end_d2_ln_exp_real_all treatment if pre == 0 [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo5
ivreghdfe end_d2_ln_exp_finanz_all treatment if pre == 0 [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo6

esttab mo1 mo2 mo3 mo4 mo5 mo6, b(3) p

ivreghdfe end_s_exp_general_sp treatment if pre == 0 [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo1
ivreghdfe end_s_exp_people_sp treatment if pre == 0  [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo2
ivreghdfe end_s_exp_culture_sp treatment if pre == 0  [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo3
ivreghdfe end_s_exp_infra_sp treatment if pre == 0 [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo4
ivreghdfe end_d2_s_exp_general_sp treatment if pre == 0 [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo5
ivreghdfe end_d2_s_exp_people_sp treatment if pre == 0  [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo6
ivreghdfe end_d2_s_exp_culture_sp treatment if pre == 0  [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo7
ivreghdfe end_d2_s_exp_infra_sp treatment if pre == 0 [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo8

esttab mo1 mo2 mo3 mo4 mo5 mo6 mo7 mo8, b(3) p

/* with state year */
ivreghdfe end_rate_tradetax treatment if pre == 0 [aw = weight_robust2], absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo1
ivreghdfe end_ln_exp_real_all treatment if pre == 0 [aw = weight_robust2] , absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo2
ivreghdfe end_ln_exp_finanz_all treatment if pre == 0 [aw = weight_robust2] , absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo3
ivreghdfe end_d2_rate_tradetax treatment if pre == 0 [aw = weight_robust2], absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo4
ivreghdfe end_d2_ln_exp_real_all treatment if pre == 0 [aw = weight_robust2] , absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo5
ivreghdfe end_d2_ln_exp_finanz_all treatment if pre == 0 [aw = weight_robust2] , absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo6
esttab mo1 mo2 mo3 mo4 mo5 mo6, b(3) p

ivreghdfe end_s_exp_general_sp treatment if pre == 0 [aw = weight_robust2] , absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo1
ivreghdfe end_s_exp_people_sp treatment if pre == 0  [aw = weight_robust2] , absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo2
ivreghdfe end_s_exp_culture_sp treatment if pre == 0  [aw = weight_robust2] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo3
ivreghdfe end_s_exp_infra_sp treatment if pre == 0 [aw = weight_robust2] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo4
ivreghdfe end_d2_s_exp_general_sp treatment if pre == 0 [aw = weight_robust2] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo5
ivreghdfe end_d2_s_exp_people_sp treatment if pre == 0  [aw = weight_robust2] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo6
ivreghdfe end_d2_s_exp_culture_sp treatment if pre == 0  [aw = weight_robust2] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo7
ivreghdfe end_d2_s_exp_infra_sp treatment if pre == 0 [aw = weight_robust2] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo8
esttab mo1 mo2 mo3 mo4 mo5 mo6 mo7 mo8, b(3) p

/* Table A4 */
/* SPD-CDU vs SPD-SPD */

#delimit ;
esttab sum4 sum5 sum6  using "$TABLES/ds_tabA4.tex"
  , replace 
  style(tex)
	booktabs
  title("Descriptive Statistics\label{tab:ds}") 
  label
  varwidth(60)
  cells("mean(fmt(2) label(Mean)) Var(fmt(2) label(Variance))")   
  nonumbers 
  nonotes
  nodepvars
  nomtitles
  nostar
  substitute(\begin{tabular} "\begin{threeparttable}\scriptsize\begin{tabular}" \end{tabular} "\end{tabular}\begin{tablenotes}\item \textit{Source:} Own data collection and calculations. \textit{Notes:} Calculations are based on a sample with majors for \$`nmun'\$ municipalities and the year 2006.\end{tablenotes}\end{threeparttable}") ;
#delimit cr

/* Testing for Differences */
/* without controls */
ivreghdfe end_rate_tradetax treatment if pre == 1  [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo1
ivreghdfe end_ln_exp_real_all treatment if pre == 1 [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo2
ivreghdfe end_ln_exp_finanz_all treatment if pre == 1 [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo3
ivreghdfe end_d2_rate_tradetax treatment if pre == 1  [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo4
ivreghdfe end_d2_ln_exp_real_all treatment if pre == 1 [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo5
ivreghdfe end_d2_ln_exp_finanz_all treatment if pre == 1 [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo6

esttab mo1 mo2 mo3 mo4 mo5 mo6, b(3) p

ivreghdfe end_s_exp_general_sp treatment if pre == 1 [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo1
ivreghdfe end_s_exp_people_sp treatment if pre == 1  [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo2
ivreghdfe end_s_exp_culture_sp treatment if pre == 1  [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo3
ivreghdfe end_s_exp_infra_sp treatment if pre == 1 [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo4
ivreghdfe end_d2_s_exp_general_sp treatment if pre == 1 [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo5
ivreghdfe end_d2_s_exp_people_sp treatment if pre == 1  [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo6
ivreghdfe end_d2_s_exp_culture_sp treatment if pre == 1  [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo7
ivreghdfe end_d2_s_exp_infra_sp treatment if pre == 1 [aw = weight_robust2], robust cluster(id_AGS_unique election_period)
eststo mo8

esttab mo1 mo2 mo3 mo4 mo5 mo6 mo7 mo8, b(3) p

/* With state-year */
ivreghdfe end_rate_tradetax treatment if pre == 1 [aw = weight_robust2], absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo1
ivreghdfe end_ln_exp_real_all treatment if pre == 1 [aw = weight_robust2] , absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo2
ivreghdfe end_ln_exp_finanz_all treatment if pre == 1 [aw = weight_robust2] , absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo3
ivreghdfe end_d2_rate_tradetax treatment if pre == 1 [aw = weight_robust2], absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo4
ivreghdfe end_d2_ln_exp_real_all treatment if pre == 1 [aw = weight_robust2] , absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo5
ivreghdfe end_d2_ln_exp_finanz_all treatment if pre == 1 [aw = weight_robust2] , absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo6
esttab mo1 mo2 mo3 mo4 mo5 mo6, b(3) p

ivreghdfe end_s_exp_general_sp treatment if pre == 1 [aw = weight_robust2] , absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo1
ivreghdfe end_s_exp_people_sp treatment if pre == 1  [aw = weight_robust2] , absorb(state_year) robust cluster(id_AGS_unique election_period)
eststo mo2
ivreghdfe end_s_exp_culture_sp treatment if pre == 1  [aw = weight_robust2] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo3
ivreghdfe end_s_exp_infra_sp treatment if pre == 1 [aw = weight_robust2] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo4
ivreghdfe end_d2_s_exp_general_sp treatment if pre == 1 [aw = weight_robust2] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo5
ivreghdfe end_d2_s_exp_people_sp treatment if pre == 1  [aw = weight_robust2] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo6
ivreghdfe end_d2_s_exp_culture_sp treatment if pre == 1  [aw = weight_robust2] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo7
ivreghdfe end_d2_s_exp_infra_sp treatment if pre == 1 [aw = weight_robust2] , absorb(state_year)  robust cluster(id_AGS_unique election_period)
eststo mo8
esttab mo1 mo2 mo3 mo4 mo5 mo6 mo7 mo8, b(3) p

